<?php
/*
Plugin Name: Uki Cocoon Customizer
Plugin URI: https://toach.click/
Description: A customizer plugin for Uki theme.
Version: 3.0.0
Author: Ukidaira
Author URI: https://toach.click/
License: GPL-2.0+
License URI: http://www.gnu.org/licenses/gpl-2.0.txt
*/


function uki_enqueue_customizer_styles()
{
    wp_enqueue_style('uki-cocoon-customizer-css', plugin_dir_url(__FILE__) . 'uki-cocoon-customizer.css', array(), '1.0.0');
    wp_enqueue_style('uki-cocoon-customizer-admin-css', plugin_dir_url(__FILE__) . 'uki-cocoon-customizer-admin.css', array(), '1.0.0');
}

add_action('wp_enqueue_scripts', 'uki_enqueue_customizer_styles');
add_action('customize_controls_enqueue_scripts', 'uki_enqueue_customizer_styles');

function uki_customizer_settings($wp_customize)
{
    $wp_customize->add_section('uki_colors_section', array(
        'title' => 'うきCocoon設定',
        'priority' => 30,
    ));

    $wp_customize->add_setting('uki_main_color', array(
        'default' => '#9ca6bb',
        'sanitize_callback' => 'sanitize_hex_color',
        'transport' => 'postMessage'
    ));

    $wp_customize->add_control(new WP_Customize_Color_Control($wp_customize, 'uki_main_color', array(
        'label' => 'メインカラー',
        'section' => 'uki_colors_section',
        'settings' => 'uki_main_color',
    )));

    // 角丸を解除チェックボックスの追加
    $wp_customize->add_setting('uki_remove_rounded_corners', array(
        'default' => false,
        'sanitize_callback' => 'sanitize_checkbox',
    ));

    $wp_customize->add_control('uki_remove_rounded_corners', array(
        'label' => '角丸を解除',
        'section' => 'uki_colors_section',
        'type' => 'checkbox',
    ));

    // 完全フラット化（影を非表示）チェックボックスの追加
    $wp_customize->add_setting('uki_full_flat', array(
        'default' => false,
        'sanitize_callback' => 'sanitize_checkbox',
    ));

    $wp_customize->add_control('uki_full_flat', array(
        'label' => '完全フラット化（影を非表示）',
        'section' => 'uki_colors_section',
        'type' => 'checkbox',
    ));

    $wp_customize->add_setting('uki_header_container_bg_color', array(
        'default' => '#ffffff',
        'sanitize_callback' => 'sanitize_hex_color',
        'transport' => 'postMessage'
    ));

    $wp_customize->add_control(new WP_Customize_Color_Control($wp_customize, 'uki_header_container_bg_color', array(
        'label' => 'ヘッダーの背景色',
        'section' => 'uki_colors_section',
        'settings' => 'uki_header_container_bg_color',
    )));

    $wp_customize->add_setting('uki_site_name_text_color', array(
        'default' => '#666666',
        'sanitize_callback' => 'sanitize_hex_color',
        'transport' => 'postMessage'
    ));

    $wp_customize->add_control(new WP_Customize_Color_Control($wp_customize, 'uki_site_name_text_color', array(
        'label' => 'ヘッダーの文字色',
        'section' => 'uki_colors_section',
        'settings' => 'uki_site_name_text_color',
    )));

    $wp_customize->add_setting('uki_footer_widget_bg_color', array(
        'default' => '',
        'sanitize_callback' => 'sanitize_hex_color',
        'transport' => 'postMessage'
    ));

    $wp_customize->add_control(new WP_Customize_Color_Control($wp_customize, 'uki_footer_widget_bg_color', array(
        'label' => 'フッターウィジェットの背景色',
        'section' => 'uki_colors_section',
        'settings' => 'uki_footer_widget_bg_color',
    )));

    $wp_customize->add_setting('uki_footer_bg_color', array(
        'default' => '#ffffff',
        'sanitize_callback' => 'sanitize_hex_color',
        'transport' => 'postMessage'
    ));

    $wp_customize->add_setting('uki_footer_text_color', array(
        'default' => '',
        'sanitize_callback' => 'sanitize_hex_color',
        'transport' => 'postMessage'
    ));

    $wp_customize->add_control(new WP_Customize_Color_Control($wp_customize, 'uki_footer_text_color', array(
        'label' => 'フッターテキストの色',
        'section' => 'uki_colors_section',
        'settings' => 'uki_footer_text_color',
    )));

    $wp_customize->add_control(new WP_Customize_Color_Control($wp_customize, 'uki_footer_bg_color', array(
        'label' => 'フッターの背景色',
        'section' => 'uki_colors_section',
        'settings' => 'uki_footer_bg_color',
    )));
}
add_action('customize_register', 'uki_customizer_settings');

function uki_customizer_live_preview()
{
    ob_start();
?>
    <script type="text/javascript">
        (function() {
            document.addEventListener("DOMContentLoaded", () => {
                wp.customize("uki_main_color", (value) => {
                    value.bind((to) => {
                        document.documentElement.style.setProperty("--uki-main-color", to);
                        document.documentElement.style.setProperty("--uki-main-color-transparent-f", hex2rgba(to, 0.08));
                        document.documentElement.style.setProperty("--uki-main-color-transparent-h", hex2rgba(to, 0.15));
                        document.documentElement.style.setProperty("--uki-main-color-transparent-b", hex2rgba(to, 0.05));
                    });
                });

                wp.customize("uki_header_container_bg_color", (value) => {
                    value.bind((to) => {
                        document.querySelector("#header-container").style.backgroundColor = to;
                        document.querySelector("#header-container .navi").style.backgroundColor = "transparent";
                    });
                });

                wp.customize("uki_site_name_text_color", (value) => {
                    value.bind((to) => {
                        document.querySelector(".site-name-text").style.color = to;
                        document.querySelectorAll(".navi-in a").forEach(elem => {
                            elem.style.color = to;
                        });
                    });
                });

                wp.customize("uki_footer_widget_bg_color", (value) => {
                    value.bind((to) => {
                        document.querySelectorAll("#container .footer .widget").forEach(elem => {
                            elem.style.backgroundColor = to;
                        });
                    });
                });

                wp.customize("uki_footer_text_color", (value) => {
                    value.bind((to) => {
                        document.querySelectorAll("#container .footer h3, #container .footer .widget, #container .footer a:not(.tagcloud a)").forEach(elem => {
                            elem.style.color = to;
                        });
                    });
                });

                wp.customize("uki_footer_bg_color", (value) => {
                    value.bind((to) => {
                        document.querySelector(".footer").style.backgroundColor = to;
                    });
                });

                function hex2rgba(hex, opacity) {
                    const bigint = parseInt(hex.slice(1), 16),
                        r = (bigint >> 16) & 255,
                        g = (bigint >> 8) & 255,
                        b = bigint & 255;

                    if (opacity) {
                        return `rgba(${r}, ${g}, ${b}, ${opacity})`;
                    } else {
                        return `rgb(${r}, ${g}, ${b})`;
                    }
                }
            });
        })();
    </script>

<?php
    $script = ob_get_clean();
    wp_add_inline_script('customize-preview', $script);
}

add_action('customize_preview_init', 'uki_customizer_live_preview');

function uki_customize_css()
{
    $main_color = get_theme_mod('uki_main_color', '#9ca6bb');
    $header_container_bg_color = get_theme_mod('uki_header_container_bg_color', '#ffffff');
    $site_name_text_color = get_theme_mod('uki_site_name_text_color', '#666666');
    $footer_widget_bg_color = get_theme_mod('uki_footer_widget_bg_color', '');
    $footer_bg_color = get_theme_mod('uki_footer_bg_color', '#ffffff');
    $remove_rounded_corners = get_theme_mod('uki_remove_rounded_corners', false);
    $full_flat = get_theme_mod('uki_full_flat', false);
?>

    <style type="text/css">
        :root {
            --uki-main-color: <?php echo $main_color; ?>;
            --uki-main-color-transparent-f: <?php echo hex2rgba($main_color, 0.08); ?>;
            --uki-main-color-transparent-h: <?php echo hex2rgba($main_color, 0.15); ?>;
            --uki-main-color-transparent-b: <?php echo hex2rgba($main_color, 0.05); ?>;
        }

        #header-container {
            background-color: <?php echo $header_container_bg_color; ?>;
        }

        #header-container .navi {
            background-color: transparent;
        }

        .site-name-text,
        .navi-in a {
            color: <?php echo $site_name_text_color; ?>;
        }

        #container .footer h3,
        #container .footer .widget,
        #container .footer a:not(.tagcloud a) {
            color: <?php echo get_theme_mod('uki_footer_text_color', ''); ?>;
        }


        .tagcloud a {
            color: inherit;
        }


        .footer {
            background-color: <?php echo $footer_bg_color; ?>;
        }

        <?php if ($remove_rounded_corners) : ?>*:not(.author-box img):not(.cat-label):not(.sns-follow-buttons a):not(.tagcloud a):not(.page-numbers):not(.cat-link):not(.fa-circle-chevron-up) {
            border-radius: 0 !important;
        }

        <?php endif; ?><?php if ($full_flat) : ?>* {
            box-shadow: none !important;
        }

        <?php endif; ?>
    </style>

<?php
}
add_action('wp_head', 'uki_customize_css');



function hex2rgba($color, $opacity = false)
{
    $default = 'rgba(0,0,0,0)';
    if (strlen($color) == 4 || strlen($color) == 7) {
        $color = ltrim($color, '#');

        if (strlen($color) == 3) {
            $color = $color[0] . $color[0] . $color[1] . $color[1] . $color[2] . $color[2];
        }

        $r = hexdec(substr($color, 0, 2));
        $g = hexdec(substr($color, 2, 2));
        $b = hexdec(substr($color, 4, 2));

        if ($opacity) {
            return "rgba($r, $g, $b, $opacity)";
        } else {
            return "rgb($r, $g, $b)";
        }
    }
    return $default;
}

function sanitize_checkbox($input)
{
    if ($input === true || $input === '1') {
        return true;
    }
    return false;
}

function enqueue_jquery()
{
    wp_enqueue_script('jquery');
}
add_action('wp_enqueue_scripts', 'enqueue_jquery');

function toc_highlight_js()
{
    echo '
    <script>
        jQuery(document).ready(function () {
            var tocLinks = jQuery(".toc-list a");
            var sections = tocLinks.map(function () {
                var targetId = jQuery(this).attr("href");
                return jQuery(targetId);
            });

            jQuery(window).on("scroll", function () {
                var currentScrollPosition = jQuery(this).scrollTop() + (jQuery(window).height() * 0.10);
                var currentSection;
                sections.each(function (i) {
                    if (jQuery(this).offset().top - 1 < currentScrollPosition) {
                        currentSection = tocLinks[i];
                    }
                });

                tocLinks.removeClass("active");
                if (currentSection) {
                    jQuery(currentSection).addClass("active");
                }
            });
        });
    </script>';
}

add_action('wp_footer', 'toc_highlight_js');
